<?php

namespace Drupal\fieldory_examples\Commands;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\fieldory\FieldoryManger;
use Drupal\node\Entity\NodeType;
use Drush\Commands\DrushCommands;

/**
 * Class FieldoryExamplesCommands.
 *
 * @package Drupal\fieldory_examples\Commands
 */
class FieldoryExamplesCommands extends DrushCommands {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  private $entityTypeManager;

  /**
   * The fieldory manager.
   *
   * @var \Drupal\fieldory\FieldoryManger
   */
  private $fieldoryManager;

  /**
   * ApplyToCommands constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\fieldory\FieldoryManger $fieldory_manager
   *   The fieldory manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager, FieldoryManger $fieldory_manager) {
    parent::__construct();
    $this->entityTypeManager = $entity_type_manager;
    $this->fieldoryManager = $fieldory_manager;
  }

  /**
   * Example usages for the fieldory module.
   *
   * @command fieldory_examples:demo
   * @aliases fedemo
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   * @throws \Drupal\Core\Entity\EntityStorageException
   * @throws \Drupal\fieldory\Exception\InvalidFieldoryException
   */
  public function demo() {

    $this->fieldoryManager->getFieldoryInstance('string')
      ->init(NodeType::class, 'node', 'Fieldory', 'A String Field')
      ->run();

  }

}
