<?php

namespace Drupal\fieldory\MinimalOptions;

use Drupal\fieldory\Exception\InvalidMinimalOptionException;
use Drupal\fieldory\MinimalOptionBase;

/**
 * Class BoolFieldOption.
 *
 * @property-read $onLabel The on label.
 * @property-read $offLabel The off label.
 */
class BoolFieldOption extends MinimalOptionBase {

  /**
   * The on label.
   *
   * @var string
   */
  private $onLabel;
  /**
   * The off label.
   *
   * @var string
   */
  private $offLabel;

  /**
   * BoolFieldOption constructor.
   *
   * @param string $on_label
   *   The on label.
   * @param string $off_label
   *   The off label.
   */
  public function __construct($on_label = 'Yes', $off_label = 'No') {
    $this->onLabel = $on_label;
    $this->offLabel = $off_label;
  }

  /**
   * Implements read-only properties.
   *
   * @param string $name
   *   The property name.
   *
   * @return string|null
   *   The label.
   *
   * @throws \Drupal\fieldory\Exception\InvalidMinimalOptionException
   */
  public function __get($name) {
    $this->validate();
    if ('onLabel' === $name) {
      return $this->onLabel;
    }
    if ('offLabel' === $name) {
      return $this->offLabel;
    }
  }

  /**
   * Validate if the option is valid.
   *
   * @throws \Drupal\fieldory\Exception\InvalidMinimalOptionException
   */
  public function validate() {
    if (empty($this->onLabel) || empty($this->offLabel)) {
      throw new InvalidMinimalOptionException();
    }
  }

}
