<?php

namespace Drupal\fieldory\MinimalOptions;

use Drupal\fieldory\Exception\InvalidMinimalOptionException;
use Drupal\fieldory\MinimalOptionBase;

/**
 * Class StateFieldOption.
 *
 * @property-read $defaultValue The default value.
 * @property-read $workflow The workflow.
 */
class StateFieldOption extends MinimalOptionBase {

  /**
   * The default value of the workflow.
   *
   * @var array
   */
  private $defaultValue;

  /**
   * The workflow used.
   *
   * @var string
   */
  private $workflow;

  /**
   * StateFieldOption constructor.
   *
   * @param string $default_state
   *   The machine name of the default state.
   * @param string $workflow
   *   The workflow used.
   */
  public function __construct($default_state, $workflow) {
    $this->defaultValue = [
      ['value' => $default_state],
    ];
    $this->workflow = $workflow;
  }

  /**
   * Implements read-only properties.
   *
   * @param string $name
   *   The property name.
   *
   * @return mixed
   *   The peroperty value.
   *
   * @throws \Drupal\fieldory\Exception\InvalidMinimalOptionException
   */
  public function __get($name) {
    $this->validate();
    if ('defaultValue' === $name) {
      return $this->defaultValue;
    }
    if ('workflow' === $name) {
      return $this->workflow;
    }
  }

  /**
   * Validate if the option is valid.
   *
   * @throws \Drupal\fieldory\Exception\InvalidMinimalOptionException
   */
  public function validate() {
    if (empty($this->defaultValue) || empty($this->workflow)) {
      throw new InvalidMinimalOptionException();
    }
  }

}
