<?php

namespace Drupal\fieldory\Plugin\Fieldory;

use Drupal\fieldory\FieldoryBase;
use Drupal\fieldory\MinimalOptionBase;
use Drupal\fieldory\MinimalOptions\BoolFieldOption;

/**
 * Class BoolField.
 *
 * @Fieldory(
 *     id = "bool",
 *     description = "Fieldory for bool field",
 * )
 */
class BoolField extends FieldoryBase {

  /**
   * The field type.
   *
   * @var string
   */
  protected $fieldType = 'boolean';

  /**
   * BoolField constructor.
   */
  public function __construct() {
    $this->setFieldSettings([
      'on_label' => 'Yes',
      'off_label' => 'No',
    ]);
    $this->setFieldFormOptions(['type' => 'boolean_checkbox']);
    $this->setFieldViewOptions(['type' => 'boolean']);
  }

  /**
   * Set minimal option.
   *
   * @inheritDoc
   */
  public function setMinimalSettings(MinimalOptionBase $option) {
    if ($option instanceof BoolFieldOption) {
      $this->optionalSetLabels($option);
    }
    return $this;
  }

  /**
   * Set minimal option.
   *
   * @param \Drupal\fieldory\MinimalOptions\BoolFieldOption $option
   *   The option instance.
   */
  private function optionalSetLabels(BoolFieldOption $option) {
    $this->setFieldSettings([
      'on_label' => $option->onLabel,
      'off_label' => $option->offLabel,
    ]);
  }

}
